import { LocalStorage, Platform } from 'quasar';
import { Preferences } from '@capacitor/preferences';

// eslint-disable-next-line @typescript-eslint/no-explicit-any
type PersitentTypes = Date | RegExp | number | boolean | string | object;

export class PersistentStorage {
  static clear() {
    if (Platform.is.capacitor) return Preferences.clear();
    else return Promise.resolve(LocalStorage.clear());
  }

  static remove(key: string) {
    if (Platform.is.capacitor) return Preferences.remove({ key: key });
    else return Promise.resolve(LocalStorage.remove(key));
  }

  static set(key: string, value: PersitentTypes) {
    if (Platform.is.capacitor) return Preferences.set({ key, value: JSON.stringify(value) });
    else return Promise.resolve(LocalStorage.set(key, value));
  }

  static get<T extends PersitentTypes>(key: string) {
    if (Platform.is.capacitor)
      return Preferences.get({ key }).then((v) =>
        v.value === null ? null : (JSON.parse(v.value) as T)
      );
    else return Promise.resolve(LocalStorage.getItem<T>(key));
  }

  static keys() {
    if (Platform.is.capacitor) return Preferences.keys().then((v) => v.keys);
    else return Promise.resolve(LocalStorage.getAllKeys());
  }
}
