/**
 * This boot file registers login / authentification related axios interceptors
 */
import { useMainStore, hasPermissions } from '@flaschengeist/api';
import { boot } from 'quasar/wrappers';

export default boot(({ router }) => {
  /**
   * Login guard
   * Check if user tries to access the secured area and validates token
   */
  router.beforeEach((to, from) => {
    const store = useMainStore();

    // Skip loops
    if (to.name == 'login' && from.name == 'login') return false;

    // Secured area '/in/...' requires to be authenticated
    if (to.path.startsWith('/in') && (!store.session || store.session.expires <= new Date())) {
      store.handleLoggedOut();
      return { name: 'login' };
    }
  });

  /**
   * Permission guard
   * Check permissions for route, cancel navigation on errors
   */
  router.beforeResolve((to) => {
    if (!!to.meta.permissions && !hasPermissions(<FG.Permission[]>to.meta.permissions))
      return false;
  });
});
